==> goreleaser-1.18.2.tar.gz: goreleaser-1.18.2/www/docs/users.md <==
## Who uses GoReleaser?

As the GoReleaser Community grows, we'd like to keep a list of our users.

Here's a running list of some organizations using GoReleaser[^1]:

1. [Anchore](https://anchore.com)
1. [Authzed](https://authzed.com)
1. [Ayedo](https://www.ayedo.de/)
1. [Caddy](https://caddyserver.com)
1. [Charm](https://charm.sh)
1. [Comcast](https://comcast.github.io)
1. [Compose Generator](https://www.compose-generator.com)
1. [Conduit](https://www.conduit.io/)
1. [CrowdStrike](https://www.crowdstrike.com)
1. [Crusoe Cloud](https://crusoecloud.com)
1. [Curio](https://curio.sh)
1. [DeepSource](https://deepsource.io)
1. [EVCC](https://evcc.io)
1. [Fleet for osquery](https://fleetdm.com)
1. [GitGuardian](https://gitguardian.com)
1. [GitHub](https://github.com)
1. [Gitleaks](https://gitleaks.io)
1. [Go Buffalo](https://gobuffalo.io)
1. [GolangCI](https://golangci.com)
1. [Goldenhand Software](https://www.goldenhandsoftware.co.uk)
1. [Google](https://google.com)
1. [Hashicorp](https://hashicorp.com)
1. [Helm](https://helm.sh)
1. [Hugo](https://gohugo.io)
1. [IRON Security](https://iron.security)
1. [Koordinator](https://koordinator.sh)
1. [KSOC](https://www.ksoc.com/)
1. [KusionStack](https://kusionstack.io/)
1. [Mercure](https://mercure.rocks/)
1. [Meroxa](https://meroxa.com/)
1. [Microsoft](https://microsoft.com)
1. [Minio](https://min.io)
1. [Ministry of Justice (UK)](https://mojdigital.blog.gov.uk)
1. [NATS](https://nats.io)
1. [Numary](https://numary.com)
1. [OpenFeature](https://openfeature.dev)
1. [Optimus Mine](https://optimusmine.com)
1. [Planetscale](https://planetscale.com)
1. [Pulumi](https://pulumi.com)
1. [prestd](https://prestd.com)
1. [Schwarz IT](https://jobs.schwarz)
1. [SemaphoreCI](https://semaphoreci.com)
1. [Sigstore](https://sigstore.dev)
1. [Splunk](http://dev.splunk.com)
1. [Sysdig](https://sysdig.com)
1. [TOTVS Labs](https://totvslabs.com)
1. [Trendyol](https://trendyol.com)
1. [Trybe](https://betrybe.com)

Feel free to [add yours](https://github.com/goreleaser/goreleaser/edit/main/USERS.md)!

<!--
Hey! Thanks for looking into this file!
If you're going to edit it, please:
- keep a-z ordering :)
- edit only the USERS.md file at the repository's root folder
- /www/docs/users.md is auto-copied from /USERS.md
-->

[^1]: Entries were either added by the companies themselves or by the maintainers after seeing it in the wild.
      You can see all public repositories using GoReleaser by [searching on GitHub](https://github.com/search?q=filename%3Agoreleaser+language%3Ayaml+path%3A%2F).

==> goreleaser-1.24.0.tar.gz: goreleaser-1.24.0/www/docs/users.md <==
## Who uses GoReleaser?

As the GoReleaser Community grows, we'd like to keep a list of our users.

Here's a running list of some organizations using GoReleaser[^1]:

1. [Anchore](https://anchore.com)
1. [Aqua Security](https://www.aquasec.com)
1. [Authzed](https://authzed.com)
1. [Ayedo](https://www.ayedo.de/)
1. [Banzai Cloud](https://banzaicloud.com)
1. [Bitnami](https://bitnami.com)
1. [Caddy](https://caddyserver.com)
1. [Charm](https://charm.sh)
1. [Comcast](https://comcast.github.io)
1. [Compose Generator](https://www.compose-generator.com)
1. [Conduit](https://www.conduit.io/)
1. [CrowdStrike](https://www.crowdstrike.com)
1. [Crusoe Cloud](https://crusoecloud.com)
1. [Curio](https://curio.sh)
1. [Dagger](https://dagger.io)
1. [DeepSource](https://deepsource.io)
1. [EVCC](https://evcc.io)
1. [FabioLB](https://fabiolb.net)
1. [Fleet for osquery](https://fleetdm.com)
1. [Flipt](https://www.flipt.io)
1. [FluxCD](https://fluxcd.io)
1. [Gaia Pipeline](https://github.com/gaia-pipeline)
1. [GitGuardian](https://gitguardian.com)
1. [GitHub](https://github.com)
1. [Gitleaks](https://gitleaks.io)
1. [Go Buffalo](https://gobuffalo.io)
1. [GolangCI](https://golangci.com)
1. [Goldenhand Software](https://www.goldenhandsoftware.co.uk)
1. [Google](https://google.com)
1. [Grafana](https://grafana.com)
1. [Hashicorp](https://hashicorp.com)
1. [Helm](https://helm.sh)
1. [Hugo](https://gohugo.io)
1. [IRON Security](https://iron.security)
1. [KSOC](https://www.ksoc.com/)
1. [Ko Build](https://ko.build)
1. [Koordinator](https://koordinator.sh)
1. [Kubernetes SIGs](https://github.com/kubernetes-sigs)
1. [KusionStack](https://kusionstack.io/)
1. [Mercure](https://mercure.rocks/)
1. [Meroxa](https://meroxa.com/)
1. [Micro](https://micro.dev)
1. [Microsoft](https://microsoft.com)
1. [Minio](https://min.io)
1. [Ministry of Justice (UK)](https://mojdigital.blog.gov.uk)
1. [NATS](https://nats.io)
1. [NextDNS](https://nextdns.io)
1. [Numary](https://numary.com)
1. [Open Telemetry](https://opentelemetry.io)
1. [OpenFeature](https://openfeature.dev)
1. [OpenSSF](https://openssf.org)
1. [Optimus Mine](https://optimusmine.com)
1. [Parca](https://www.parca.dev)
1. [Pdfcpu](https://pdfcpu.io)
1. [Planetscale](https://planetscale.com)
1. [Prestd](https://prestd.com)
1. [Pulumi](https://pulumi.com)
1. [ReviewDog](https://github.com/reviewdog)
1. [Rixo](https://www.rixo.cz)
1. [Schwarz IT](https://jobs.schwarz)
1. [SecureGo](https://securego.io)
1. [SemaphoreCI](https://semaphoreci.com)
1. [Shopify](https://shopify.engineering)
1. [Sigstore](https://sigstore.dev)
1. [Snyk](https://snyk.io)
1. [Splunk](http://dev.splunk.com)
1. [StackExchange](https://stackexchange.com)
1. [Sysdig](https://sysdig.com)
1. [TOTVS Labs](https://totvslabs.com)
1. [Tilt](https://tilt.dev)
1. [Traefik](https://traefik.io)
1. [Trendyol](https://trendyol.com)
1. [Trybe](https://betrybe.com)
1. [Uber](https://uber.github.io/)
1. [Updatecli](https://updatecli.io/)
1. [VMWare](https://www.vmware.com)
1. [Weave Works](https://www.weave.works)
1. [Zitatel](https://zitadel.com)

Feel free to [add yours](https://github.com/goreleaser/goreleaser/edit/main/USERS.md)!

<!--
Hey! Thanks for looking into this file!
If you're going to edit it, please:
- keep a-z ordering :)
- edit only the USERS.md file at the repository's root folder
- /www/docs/users.md is auto-copied from /USERS.md
-->

[^1]:
    Entries were either added by the companies themselves or by the maintainers after seeing it in the wild.
    You can see all public repositories using GoReleaser by [searching on GitHub](https://github.com/search?q=path%3A.goreleaser.yml+OR+path%3A.goreleaser.yaml+&type=code).
